@@ -1,6 +1,6 @@
 """Generates a layout for a chip with a cutback sweep."""
+
 from functools import partial
-import pandas as pd
 import gdsfactory as gf
 
 
@@ -10,15 +10,19 @@ add_gc = gf.routing.add_fiber_array
 ring_double = gf.components.cutback_loss_mmi1x2
 
 
-@gf.cell
+@gf.cell(check_ports=False)
 def cutback() -> gf.Component:
     """Returns a component cutback sweep."""
+    loss = (0, 1, 2)
     cutback_sweep = gf.components.cutback_loss_mmi1x2(
-        component=gf.components.mmi1x2(),
-        loss=(0, 1, 2),
-        decorator=gf.routing.add_fiber_array,
+        component=gf.components.mmi1x2(), loss=loss
     )
-    c = pack(cutback_sweep)
+    cutback_sweep_gratings = [add_gc(c) for c in cutback_sweep]
+
+    for loss, c in zip(loss, cutback_sweep_gratings):
+        c.name = f"cutback_loss_{loss}"
+
+    c = pack(cutback_sweep_gratings)
     if len(c) > 1:
         print(f"Failed to pack in 1 component of {size}, got {len(c)}")
         c = gf.grid(c)
@@ -27,7 +31,7 @@ def cutback() -> gf.Component:
     return c
 
 
-@gf.cell
+@gf.cell(check_ports=False)
 def top() -> gf.Component:
     """Returns a top cell."""
     c = gf.Component()
@@ -36,21 +40,6 @@ def top() -> gf.Component:
     return c
 
 
-def write_settings_table() -> pd.DataFrame:
-    """Write settings table."""
-    settings = ["components"]
-    c = cutback()
-    references = c.get_dependencies()
-    rows = []
-    for r in references:
-        d = dict(cell=r.name)
-        for s in settings:
-            d[s] = r.info.get(s, None)
-        rows.append(d)
-
-    return pd.DataFrame(rows)
-
-
 if __name__ == "__main__":
     from gdsfactory.labels import get_test_manifest
 
