@@ -1,4 +1,5 @@
 """Generate a layout with a resistor sweep."""
+
 from functools import partial
 
 import gdsfactory as gf
@@ -10,13 +11,12 @@ add_gc = gf.routing.add_fiber_array
 length_x = 0.1
 
 
-@gf.cell(autoname=False)
+@gf.cell
 def resistance_sheet(width=10) -> gf.Component:
     """Resistor sheet."""
     c = gf.components.resistance_sheet(
         width=width,
     )
-    c.name(f"resistance-{width}-")
     return c
 
 
@@ -25,13 +25,12 @@ def resistance() -> gf.Component:
     """Resistor sweep."""
     widths = [10, 20, 100]
     sweep = [
-        gf.components.resistance_sheet(
+        resistance_sheet(
             width=width,
-            name=f"resistance-{width}-",
         )
         for width in widths
     ]
-    return gf.grid(sweep)
+    return gf.grid(sweep, shape=(len(sweep), 1))
 
 
 @gf.cell
