@@ -1,5 +1,6 @@
 # ruff: noqa: D103, D101, D102
 """Use kfactory to generate a spiral sweep."""
+
 from functools import partial
 from typing import Literal
 
@@ -7,15 +8,17 @@ import kfactory as kf
 import numpy as np
 
 
-class LAYER(kf.LayerEnum):
-    kcl = kf.constant(kf.kcl)
-    WG = (1, 0)
-    SHALLOW_ETCH = (2, 6)
-    WGCLAD = (111, 0)
-    BORDER = (10, 0)
-    FIBER_LAUNCH = (99, 0)
+class LayerInfos(kf.LayerInfos):
+    WG: kf.kdb.LayerInfo = kf.kdb.LayerInfo(1, 0)
+    SHALLOW_ETCH: kf.kdb.LayerInfo = kf.kdb.LayerInfo(2, 6)
+    WGCLAD: kf.kdb.LayerInfo = kf.kdb.LayerInfo(111, 0)
+    BORDER: kf.kdb.LayerInfo = kf.kdb.LayerInfo(10, 0)
+    FIBER_LAUNCH: kf.kdb.LayerInfo = kf.kdb.LayerInfo(99, 0)
 
 
+LAYER = LayerInfos()
+kf.kcl.infos = LAYER
+
 bend = kf.cells.circular.bend_circular(width=1, radius=10, layer=LAYER.WG)
 bend180 = kf.cells.circular.bend_circular(width=1, radius=10, layer=LAYER.WG, angle=180)
 
@@ -41,12 +44,21 @@ ridge_enc = kf.LayerEnclosure(
 
 @kf.cell
 def mmi(
-    taper_length: int = 2_000,
-    taper_width1: int = 1_000,
-    taper_width2: int = 1_5000,
-    body_width: int = 2_000,
-    body_length: int = 12_000,
-):
+    taper_length: int = 2000,
+    taper_width1: int = 1000,
+    taper_width2: int = 15000,
+    body_width: int = 2000,
+    body_length: int = 12000,
+) -> kf.KCell:
+    """Create a MMI cell.
+
+    Args:
+        taper_length: Length of the taper.
+        taper_width1: Width of the taper at the input.
+        taper_width2: Width of the taper at the output.
+        body_width: Width of the MMI body.
+        body_length: Length of the MMI body.
+    """
     c = kf.KCell()
 
     c.shapes(LAYER.WG).insert(kf.kdb.Box(12_000, 4_000))
@@ -63,12 +75,12 @@ def mmi(
     c.shapes(LAYER.WG).insert(poly.transformed(kf.kdb.Trans(2, False, 6_000, 0)))
 
     c.create_port(
-        trans=kf.kdb.Trans(2, False, -8_000, -1000), width=1000, layer=LAYER.WG
+        trans=kf.kdb.Trans(2, False, -8_000, -1000), width=1000, layer_info=LAYER.WG
     )
     c.create_port(
-        trans=kf.kdb.Trans(2, False, -8_000, 1000), width=1000, layer=LAYER.WG
+        trans=kf.kdb.Trans(2, False, -8_000, 1000), width=1000, layer_info=LAYER.WG
     )
-    c.create_port(trans=kf.kdb.Trans(8_000, 0), width=1000, layer=LAYER.WG)
+    c.create_port(trans=kf.kdb.Trans(8_000, 0), width=1000, zv=LAYER.WG)
     c.autorename_ports()
 
     return c
@@ -557,8 +569,8 @@ def TOP() -> kf.KCell:
     c1 = c << RibLoss()
     c2 = c << RidgeLoss()
 
-    c1.d.move((6450, 200))
-    c2.d.move((4200, 4500))
+    c1.dmove((6450, 200))
+    c2.dmove((4200, 4500))
 
     c.shapes(LAYER.BORDER).insert(kf.kdb.DBox(0, 0, 10_000, 10_000))
 
@@ -580,8 +592,8 @@ def grating_coupler_elliptical(
     grating_line_width: float = 0.250,
     wg_width: float = 0.5,
     neff: float = 2.6,  # tooth effective index
-    layer_taper: LAYER | None = LAYER.WG,
-    layer_trench: LAYER = LAYER.SHALLOW_ETCH,
+    layer_taper: kf.kdb.LayerInfo | None = LAYER.WG,
+    layer_trench: kf.kdb.LayerInfo = LAYER.SHALLOW_ETCH,
     p_start: int = 26,
     n_periods: int = 30,
     taper_offset: int = 0,
@@ -660,7 +672,7 @@ def grating_coupler_elliptical(
             name="o1",
             trans=kf.kdb.Trans.R180,
             width=int(wg_width / c.kcl.dbu),
-            layer=layer_taper,
+            layer_info=layer_taper,
         )
 
     c.transform(kf.kdb.Trans(int(-x_output - taper_offset), 0), no_warn=True)
@@ -676,7 +688,7 @@ def grating_coupler_elliptical(
     c.create_port(
         name="FL",
         trans=kf.kdb.Trans(x_fiber_launch, 0),
-        layer=LAYER.FIBER_LAUNCH,
+        layer_info=LAYER.FIBER_LAUNCH,
         width=100,
         port_type="fiber_launch",
     )
