@@ -1,6 +1,6 @@
 """Initiates the module."""
 # isort:skip_file
-# ruff: noqa: E402
+# ruff: noqa: E402, I001
 
 from .config import get_settings
 from doplaydo.dodata_core.models import (
@@ -23,14 +23,13 @@ ParentCell = aliased(Cell)
 settings = get_settings()
 from .engine import get_session
 
-session = get_session()
 from .db.common import attribute_filter, analysis_filter
 from .db.device_data import get_data_by_query, get_data_objects_by_query
 
 from .api.device_data import get_data_by_pkey
 from .api import analysis, cell, device, device_data, project
 
-__version__ = "0.4.5"
+__version__ = "0.6.2"
 
 # ruff: noqa: D101
 __all__ = [
@@ -54,10 +53,10 @@ __all__ = [
     "get_data_by_pkey",
     "get_data_by_query",
     "get_data_objects_by_query",
+    "get_session",
     "models",
     "or_",
     "project",
     "select",
-    "session",
     "settings",
 ]
