@@ -1,23 +1,26 @@
 """Common API calls to device_data namespace."""
+
 from __future__ import annotations
+
 import json
+from collections.abc import Sequence
+from concurrent.futures import Future, ThreadPoolExecutor, as_completed
+from io import BytesIO
+from typing import Literal
+
+import httpx
+from doplaydo.dodata_core.models import Analysis
+from PIL import Image
 from tqdm.auto import tqdm
 
-import requests
-
-from concurrent.futures import ThreadPoolExecutor, Future, as_completed
-from io import BytesIO
-from PIL import Image
-from .common import url as base_url, post, get
 from .. import settings
 from ..db.analysis import (
+    get_analyses_for_device_data,
     get_analyses_for_die,
     get_analyses_for_wafer,
-    get_analyses_for_device_data,
 )
-from doplaydo.dodata_core.models import Analysis
-from collections.abc import Sequence
-from typing import Literal
+from .common import get, post
+from .common import url as base_url
 
 
 def trigger_by_pkey(
@@ -25,7 +28,7 @@ def trigger_by_pkey(
     target_model_pkey: int,
     target_model_name: str = "die",
     parameters: dict | None = None,
-) -> requests.Response:
+) -> httpx.Response:
     """Trigger analysis.
 
     Args:
@@ -44,8 +47,6 @@ def trigger_by_pkey(
     json_parameters = json.dumps(parameters)
 
     r = post(url, params=params, json=json_parameters)
-    if r.status_code != 200:
-        raise requests.HTTPError(r.text)
     return r
 
 
@@ -66,9 +67,6 @@ def trigger_device_data(
     url = f"{base_url}/device_data/{project_id}/{device_id}/model_data"
     response = get(url)
 
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text)
-
     device_data_count = len(response.json())
     device_data_pkeys = [device_data["pkey"] for device_data in response.json()]
 
@@ -84,8 +82,6 @@ def trigger_device_data(
             target_model_name="device_data",
             parameters=parameters,
         )
-        if r.status_code != 200:
-            raise requests.HTTPError(r.text)
 
         analyses.append(Analysis(**r.json()))
     return analyses
@@ -115,7 +111,7 @@ def trigger_device_data_multi(
     parameters = parameters or []
 
     with ThreadPoolExecutor(max_workers=n_threads) as e:
-        futures: list[Future[requests.Response]] = []
+        futures: list[Future[httpx.Response]] = []
         for did, params in zip(device_data_pkeys, parameters):
             futures.append(
                 e.submit(
@@ -129,11 +125,11 @@ def trigger_device_data_multi(
         analysis_list: list[Analysis] = []
         if progress_bar:
             for future in tqdm(as_completed(futures), total=len(futures)):
-                response = future.result()
-
-                if response.status_code != 200:
+                try:
+                    response = future.result()
+                except httpx.HTTPStatusError:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise
                 analysis_list.append(Analysis(**response.json()))
 
         else:
@@ -142,7 +138,7 @@ def trigger_device_data_multi(
 
                 if response.status_code != 200:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise httpx.HTTPError(response.text)
                 analysis_list.append(Analysis(**response.json()))
         return analysis_list
 
@@ -171,7 +167,7 @@ def trigger_device_data_multi_by_pkeys(
     parameters = parameters or []
 
     with ThreadPoolExecutor(max_workers=n_threads) as e:
-        futures: list[Future[requests.Response]] = []
+        futures: list[Future[httpx.Response]] = []
         for did, params in zip(device_data_pkeys, parameters):
             futures.append(
                 e.submit(
@@ -185,20 +181,22 @@ def trigger_device_data_multi_by_pkeys(
         analysis_list: list[Analysis] = []
         if progress_bar:
             for future in tqdm(as_completed(futures), total=len(futures)):
-                response = future.result()
-
-                if response.status_code != 200:
+                try:
+                    response = future.result()
+                except httpx.HTTPStatusError:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise
                 analysis_list.append(Analysis(**response.json()))
 
         else:
             for future in as_completed(futures):
                 response = future.result()
 
-                if response.status_code != 200:
+                try:
+                    response = future.result()
+                except httpx.HTTPStatusError:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise
                 analysis_list.append(Analysis(**response.json()))
         return analysis_list
 
@@ -210,7 +208,7 @@ def trigger_die(
     die_x: int,
     die_y: int,
     parameters: dict | None = None,
-) -> requests.Response:
+) -> httpx.Response:
     """Trigger die analysis.
 
     Args:
@@ -223,8 +221,6 @@ def trigger_die(
     """
     url = f"{base_url}/die/{project_id}/{wafer_id}/{die_x}/{die_y}/"
     response = get(url)
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text)
 
     target_model_pkey = response.json()["pkey"]
     parameters = parameters or {}
@@ -273,7 +269,7 @@ def trigger_die_multi(
     dies = set(zip(die_xs, die_ys))
 
     with ThreadPoolExecutor(max_workers=n_threads) as e:
-        futures: list[Future[requests.Response]] = []
+        futures: list[Future[httpx.Response]] = []
         for wafer in wafer_ids:
             for die_x, die_y in dies:
                 for params in parameters:
@@ -290,18 +286,18 @@ def trigger_die_multi(
                     )
         if progress_bar:
             for future in tqdm(as_completed(futures), total=len(futures)):
-                response = future.result()
-
-                if response.status_code != 200:
+                try:
+                    future.result()
+                except httpx.HTTPStatusError:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise
         else:
             for future in as_completed(futures):
-                response = future.result()
-
-                if response.status_code != 200:
+                try:
+                    future.result()
+                except httpx.HTTPStatusError:
                     e.shutdown(wait=False, cancel_futures=True)
-                    raise requests.HTTPError(response.text)
+                    raise
 
 
 def trigger_wafer(
@@ -309,7 +305,7 @@ def trigger_wafer(
     analysis_function_id: str,
     wafer_id: str,
     parameters: dict | None = None,
-) -> requests.Response:
+) -> httpx.Response:
     """Trigger wafer analysis.
 
     Args:
@@ -320,8 +316,6 @@ def trigger_wafer(
     """
     url = f"{base_url}/wafer/{project_id}/{wafer_id}"
     response = get(url)
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text)
 
     target_model_pkey = response.json()["pkey"]
     parameters = parameters or {}
@@ -419,8 +413,6 @@ def _fetch_plot(analysis: Analysis) -> Image.Image:
     """Fetch plot for a given analysis."""
     url = f"{base_url}/analysis/{analysis.pkey}/summary_plot"
     response = get(url)
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text)
     return Image.open(BytesIO(response.content)).convert("RGB")
 
 
