@@ -1,8 +1,9 @@
 # ruff: noqa: D415, UP007, D103
 """DoData functions for projects."""
+
 from __future__ import annotations
 
-import requests
+import httpx
 
 from .common import url as base_url, post
 
@@ -11,7 +12,7 @@ def create(
     project_id: str,
     cell_id: str,
     attributes: dict[str, int | float | str] | None = None,
-) -> requests.Response:
+) -> httpx.Response:
     """Create a new cell for an existing project in DoData.
 
     Args:
