@@ -1,8 +1,9 @@
 """DoData functions for dies."""
+
 from __future__ import annotations
 
 
-import requests
+import httpx
 
 from .common import url as base_url, get as _get, post
 
@@ -25,7 +26,7 @@ def create(
     y: int,
     # TODO: needs attributes on die
     # attributes: dict[str, int | float | bool | str] = {},
-) -> requests.Response:
+) -> httpx.Response:
     """Upload a new die to DoData.
 
     Args:
@@ -46,15 +47,10 @@ def create(
     # return post(url, params=params, json=attributes)
     response = post(url, params=params)
 
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text, response=response)
-
     return response
 
 
 def get(project_id: str, wafer_id: str, x: int, y: int) -> Die:
     """Get a die by coordinates, project name, and wafer name."""
     die_response = _get(f"{base_url}/die/{project_id}/{wafer_id}/{x}/{y}")
-    if die_response.status_code != 200:
-        raise requests.HTTPError(die_response.text, response=die_response)
     return die_response.json()  # type: ignore[no-any-return]
