@@ -1,5 +1,6 @@
 # ruff: noqa: D415, UP007, D103
 """DoData functions for projects."""
+
 from __future__ import annotations
 
 import json
@@ -7,7 +8,7 @@ from pathlib import Path
 from typing import Optional
 
 import klayout.db as kdb
-import requests
+import httpx
 from pydantic import BaseModel
 
 from .common import url as base_url, get, post, delete as _delete
@@ -29,7 +30,7 @@ def create(
     lyp_file: Optional[str] = None,
     description: Optional[str] = None,
     cell_extractions: list[Extraction] = [],
-) -> requests.Response:
+) -> httpx.Response:
     """Upload a new project to DoData.
 
     Args:
@@ -98,7 +99,7 @@ def create(
 
 def delete(
     project_id: str,
-) -> requests.Response:
+) -> httpx.Response:
     """Delete a project from DoData."""
     url = f"{base_url}/project/{project_id}"
     return _delete(url)
@@ -210,7 +211,7 @@ def download_design_manifest(
 def upload_design_manifest(
     project_id: str,
     filepath: str | Path,
-) -> requests.Response:
+) -> httpx.Response:
     """Upload device manifest file for a project.
 
     Args:
@@ -226,7 +227,7 @@ def upload_design_manifest(
 def upload_wafer_definitions(
     project_id: str,
     filepath: str | Path,
-) -> requests.Response:
+) -> httpx.Response:
     """Upload device manifest file for a project.
 
     Args:
