@@ -1,9 +1,10 @@
 # ruff: noqa: D101, D103, D107
 """DoData functions for wafers."""
+
 from __future__ import annotations
 
 
-import requests
+import httpx
 
 from .common import url as base_url, get as _get, post
 
@@ -42,7 +43,7 @@ def create(
     wafer_id: str,
     description: str | None = None,
     lot_id: str | None = None,
-) -> requests.Response:
+) -> httpx.Response:
     """Upload a new die to DoData.
 
     Args:
@@ -62,10 +63,6 @@ def create(
         "lot_id": lot_id,
     }
     response = post(url, params=params)
-
-    if response.status_code != 200:
-        raise requests.HTTPError(response.text, response=response)
-
     return response
 
 
@@ -74,14 +71,12 @@ def get(
     wafer_id: str,
 ) -> Wafer:
     wafer_response = _get(f"{base_url}/wafer/{project_id}/{wafer_id}")
-    if wafer_response.status_code != 200:
-        raise requests.HTTPError(wafer_response.text, response=wafer_response)
     return wafer_response.json()  # type: ignore[no-any-return]
 
 
 def upload_wafer_definitions(
     project_id: str, wafer_definitions: list[WaferDefinition]
-) -> requests.Response:
+) -> httpx.Response:
     """POST wafer definitions to DoData.
 
     Args:
