@@ -1,5 +1,6 @@
 """This module contains functions for querying the database for analysis objects."""
-from .. import session, select
+
+from .. import get_session, select
 from doplaydo.dodata_core.models import (
     Die,
     Wafer,
@@ -70,6 +71,7 @@ def get_analyses_by_query(
         target_model: Whether to get analyses through wafer, die, or device_data.
         clauses: sql expressions such as `dd.Cell.cell_id == "RibLoss"`.
     """
+    session = get_session()
     statement = _get_analyses_joined_query(target_model)
 
     for clause in clauses:
@@ -100,6 +102,7 @@ def get_analyses_for_device_data(
         filter_clauses: A list of sql expressions such as `dd.Cell.cell_id == "RibLoss"`.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     query = (
         select(DeviceData)
         .join(Device)
@@ -157,6 +160,7 @@ def get_analyses_for_die(
         filter_clauses: A list of sql expressions such as `dd.Cell.cell_id == "RibLoss"`.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     die = session.exec(
         select(Die)
         .join(Wafer)
@@ -197,6 +201,7 @@ def get_analyses_for_die_by_pkey(
         limit: Limit the number of results returned.
         test_die_pkey: Check whether the die exists first.
     """
+    session = get_session()
     if test_die_pkey:
         die = session.get(Die, die_pkey)
         if die is None:
@@ -228,6 +233,7 @@ def get_analyses_for_wafer(
         filter_clauses: A list of sql expressions such as `dd.Cell.cell_id == "RibLoss"`.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     wafer = session.exec(
         select(Wafer)
         .join(Project)
@@ -259,6 +265,7 @@ def get_analyses_for_wafer_by_pkey(
         filter_clauses: A list of sql expressions such as `dd.Cell.cell_id == "RibLoss"`.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     statement = _get_analyses_joined_query(target_model=target_model).where(
         Wafer.pkey == wafer_pkey
     )
@@ -302,6 +309,7 @@ def get_analyses_by_pkey(
         limit: Limit the number of results returned.
         test_pkey: Check whether the wafer/die/device_data exists first.
     """
+    session = get_session()
     model = _get_target_model(target_model)
     if test_pkey:
         target = session.get(model, target_model_pkey)
