@@ -1,6 +1,7 @@
 """Functions for querying device data from the database."""
+
 import pandas as pd
-from .. import session, settings, ParentCell
+from .. import get_session, settings, ParentCell
 from ..api.device_data import get_data_by_pkey
 from doplaydo.dodata_core.models import Cell, Project, DeviceData, Device, Die, Wafer
 from sqlalchemy.sql import ColumnElement
@@ -8,7 +9,7 @@ from sqlmodel import select
 from sqlmodel.sql.expression import SelectOfScalar
 from tqdm.auto import tqdm
 
-import requests
+import httpx
 from concurrent.futures import ProcessPoolExecutor
 
 
@@ -43,6 +44,7 @@ def get_data_by_query(
         progress_bar: Show a progress bar.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     statement = _get_device_data_joined_query()
 
     for clause in clauses:
@@ -67,7 +69,7 @@ def get_data_by_query(
                     for result in mp_data:
                         results.append((device_data[result[0]], result[1]))
                 return results
-            except requests.HTTPError:
+            except httpx.HTTPError:
                 executor.shutdown(wait=False, cancel_futures=True)
                 raise
     else:
@@ -97,6 +99,7 @@ def get_data_objects_by_query(
         progress_bar: Show a progress bar.
         limit: Limit the number of results returned.
     """
+    session = get_session()
     statement = _get_device_data_joined_query()
 
     for clause in clauses:
