@@ -1,8 +1,9 @@
 """This modules contains functions for querying the database for wafer objects."""
+
 from doplaydo.dodata_core import models as m
 from sqlmodel.sql.expression import SelectOfScalar
 from sqlalchemy.sql import ColumnElement
-from .. import session, select
+from .. import get_session, select
 from collections.abc import Sequence
 
 
@@ -22,6 +23,7 @@ def _get_die_joined_query() -> SelectOfScalar[m.Die]:
 
 def get_dies_by_query(clauses: list[ColumnElement[bool] | bool]) -> Sequence[m.Die]:
     """Return a list of filtered wafers."""
+    session = get_session()
     statement = _get_die_joined_query()
 
     for clause in clauses:
