@@ -5,4 +5,4 @@ from sqlmodel import Session
 
 @pytest.fixture
 def session() -> Session:
-    return dd.session
+    return dd.get_session()
