@@ -1,5 +1,5 @@
 import pathlib
-import requests
+import httpx
 import pytest
 from sqlalchemy.sql import ColumnElement
 from sqlmodel.sql.expression import SelectOfScalar
@@ -65,4 +65,4 @@ if __name__ == "__main__":
         die_ys=die_ys,
         parameters=parameters,
         progress_bar=True,
-        )
+    )
