@@ -1,5 +1,5 @@
 import pathlib
-import requests
+import httpx
 import pytest
 from sqlalchemy.sql import ColumnElement
 from sqlmodel.sql.expression import SelectOfScalar
@@ -77,4 +77,4 @@ if __name__ == "__main__":
                 parameters=params,
             )
             if r.status_code != 200:
-                raise requests.HTTPError(r.text)
+                raise httpx.HTTPError(r.text)
